@@ -64,6 +64,7 @@ neon_read <- function(table = NA,
                       end_date = NA,
                       ext = NA,
                       timestamp = NA,
+                      release = NA,
                       dir = neon_dir(),
                       files = NULL,
                       sensor_metadata = TRUE,
@@ -84,6 +85,8 @@ neon_read <- function(table = NA,
                        start_date = start_date,
                        end_date = end_date,
                        ext = ext,
+                       timestamp = timestamp,
+                       release = release,
                        hash = NULL, 
                        dir = dir,
                        deprecated = FALSE)
