@@ -26,17 +26,23 @@ test_that("bigger neon_store() import", {
   skip_on_cran()
   skip_if_offline()
   
-  x <- neon_download_s3(product = "DP1.10003.001",
-                        end_date = "2019-01-01")
+  x <- neon_download(product = "DP1.10003.001",
+                     start_date="2014-01-01",
+                     end_date = "2017-01-01",
+                     type = "expanded")
+  
+  y <- neon_store(table = "brd_countdata", n = 50)
+  expect_true(nrow(y)> 0)
+  z <- neon_store(table = "brd_countdata", n = 50)
+  expect_true(is.null(z))
   
-  neon_store(table = "brd_countdata-expanded", n = 50)
   db <- neon_db()
   x <- DBI::dbListTables(db)
-  expect_true("brd_countdata-expanded" %in% x)
+  expect_true("brd_countdata-expanded-DP1.10003.001" %in% x)
   
   expect_true("provenance" %in% x)
   
-  tbl <- DBI::dbReadTable(db, "brd_countdata-expanded")
+  tbl <- DBI::dbReadTable(db, "brd_countdata-expanded-DP1.10003.001")
   expect_is(tbl, "data.frame")
   expect_true(nrow(tbl) > 0)
   expect_true(any(grepl("observerDistance", colnames(tbl))))
@@ -100,6 +106,17 @@ test_that("ECdata", {
   expect_is(x, "data.frame")
   expect_gt(nrow(x), 0)
   
+  ## confirm we omit gz 
+  x <- neon_download(product = "DP4.00200.001",
+                     site = "BART",
+                     start_date = "2020-06-01",
+                     end_date = "2020-07-01",
+                     type = "basic",
+                     dir = dir)
+  expect_equal(nrow(x), 0)
+  
+  
+  
   df <- neon_index(product = "DP4.00200.001",
                    start_date = "2020-06-01",
                    ext = "h5",
@@ -114,3 +131,21 @@ test_that("ECdata", {
   expect_gt(length(path_h5), 0)
 
 })
+
+
+
+test_that("repeated download is zero-op", {
+  
+  
+  skip_on_cran()
+  skip_if_offline()
+  
+  y <- neon_download(product = "DP1.10003.001",
+                        site = "YELL")
+
+  x <- neon_download(product = "DP1.10003.001",
+                        site = "YELL")
+  expect_is(x, "data.frame")
+  expect_equal(nrow(x), 0)
+  
+})
